import { BaseHelper } from "./base.js";
import { VideoDataError } from "@vot.js/core/utils/videoData";
import Logger from "@vot.js/shared/utils/logger";
export default class BunkrHelper extends BaseHelper {
    base64ToBytes(base64) {
        const decoded = atob(base64);
        return new Uint8Array([...decoded].map((char) => char.charCodeAt(0)));
    }
    xorDecrypt(data, key) {
        const keyBytes = new TextEncoder().encode(key);
        const result = data.map((byte, i) => byte ^ keyBytes[i % keyBytes.length]);
        return new TextDecoder().decode(result);
    }
    decryptBase64XOR(encryptedBase64, key) {
        return this.xorDecrypt(this.base64ToBytes(encryptedBase64), key);
    }
    async getVideoData(videoId) {
        try {
            const res = await this.fetch(this.origin + "/api/vs", {
                method: "POST",
                body: JSON.stringify({
                    slug: videoId,
                }),
            });
            const data = (await res.json());
            if (!data.encrypted) {
                throw new VideoDataError("Unknown Bunkr API Response");
            }
            const secret = `SECRET_KEY_` + Math.floor(data.timestamp / 3600);
            const decryptedUrl = this.decryptBase64XOR(data.url, secret);
            if (!decryptedUrl.includes(".mp4")) {
                throw new VideoDataError("Decrypted url isn't have .mp4 extension");
            }
            return {
                url: decryptedUrl,
            };
        }
        catch (err) {
            Logger.error(`Failed to get Bunkr video data, because ${err.message}`);
            return undefined;
        }
    }
    async getVideoId(url) {
        return /\/f\/([^/]+)/.exec(url.pathname)?.[1];
    }
}
