import { BaseHelper } from "./base.js";
import Logger from "@vot.js/shared/utils/logger";
export default class EpicGamesHelper extends BaseHelper {
    API_ORIGIN = "https://dev.epicgames.com/community/api/learning";
    async getPostInfo(videoId) {
        try {
            const res = await this.fetch(`${this.API_ORIGIN}/post.json?hash_id=${videoId}`);
            return (await res.json());
        }
        catch (err) {
            Logger.error(`Failed to get epicgames post info by videoId: ${videoId}.`, err.message);
            return false;
        }
    }
    async fetchPlaylistUrl(embedId) {
        try {
            const res = await this.fetch(`https://dev.epicgames.com/community/api/cms/videos/${embedId}/embed.html`);
            const content = await res.text();
            const playlistUrl = /videoUrl\s?=\s"([^"]+)"?/.exec(content);
            return playlistUrl?.[1]?.replace("qsep://", "https://");
        }
        catch (err) {
            Logger.error(`Failed to get playlist url by embed Id ${embedId}, because: ${err.message}`);
            return undefined;
        }
    }
    async getVideoData(videoId) {
        const postInfo = await this.getPostInfo(videoId);
        if (!postInfo) {
            return undefined;
        }
        const videoBlock = postInfo.blocks.find((block) => block.type === "video");
        if (!videoBlock) {
            return undefined;
        }
        const playlistUrl = await this.fetchPlaylistUrl(videoBlock.video_id);
        if (!playlistUrl) {
            return undefined;
        }
        const { title, description } = postInfo;
        return {
            url: playlistUrl,
            title,
            description,
        };
    }
    async getVideoId(url) {
        return /\/(\w{3,5})\/[^/]+$/.exec(url.pathname)?.[1];
    }
}
